#include "StdAfx.h"
#include "WorkGroupButtons.h"
#include "CommonFunction.h"

DUI_BEGIN_MESSAGE_MAP(CWorkGroupButtons, EmbeddedDUIInMFCWindow, FALSE)
DUI_ON_MSGTYPE(DUI_MSGTYPE_WINDOWINIT, OnPrepare)

DUI_ON_CLICK_CTRNAME(_T("btn_add"), _OnNotifyBtnAddClick)
DUI_ON_CLICK_CTRNAME(_T("btn_chat"), _OnNotifyBtnChatClick)
DUI_ON_CLICK_CTRNAME(_T("btn_memo"), _OnNotifyBtnMemoClick)
DUI_END_MESSAGE_MAP()

const DWORD TEXT_COLOR = 0x5e5f6d;

CWorkGroupButtons::CWorkGroupButtons(CWnd* pParent,  IWorkGroupButtonsCallBack* pCallBack)
:EmbeddedDUIInMFCWindow (pParent)
{
	m_pBtnAdd = NULL;
	m_pBtnChat = NULL;
	m_pBtnMemo = NULL;
	m_pCallBack = pCallBack;
}

CWorkGroupButtons::~CWorkGroupButtons(void)
{
}

LPCTSTR CWorkGroupButtons::GetWindowClassName() const
{
	return _T("WorkGroupButtons");
}

void CWorkGroupButtons::OnPrepare( TNotifyUI& msg )
{
	m_pBtnAdd = static_cast<CButtonUI*>(m_PaintManager.FindControl(_T("btn_add")));

	ASSERT(m_pBtnAdd);
	if(m_pBtnAdd != NULL)
	{
		m_pBtnAdd->SetFont(GetDefaultFontIndex());
		m_pBtnAdd->SetText(LoadStringFromResource(IDS_STRING139));
		m_pBtnAdd->SetTextColor(TEXT_COLOR);
	}

	m_pBtnChat = static_cast<CButtonUI*>(m_PaintManager.FindControl(_T("btn_chat")));

	ASSERT(m_pBtnChat);
	if(m_pBtnChat != NULL)
	{
		m_pBtnChat->SetFont(GetDefaultFontIndex());
		m_pBtnChat->SetText(LoadStringFromResource(IDS_STRING117));
		m_pBtnChat->SetTextColor(TEXT_COLOR);
	}

	m_pBtnMemo = static_cast<CButtonUI*>(m_PaintManager.FindControl(_T("btn_memo")));

	ASSERT(m_pBtnMemo);
	if(m_pBtnMemo != NULL)
	{
		m_pBtnMemo->SetFont(GetDefaultFontIndex());
		m_pBtnMemo->SetText(LoadStringFromResource(IDS_STRING118));
		m_pBtnMemo->SetTextColor(TEXT_COLOR);
	}
}

void CWorkGroupButtons::LoadSkin()
{
	m_PaintManager.Init(m_hWnd);
	CDialogBuilder dlgBuilder;
	CDialogBuilderCallback<CWorkGroupButtons> cb(this);
	CControlUI* pRoot = dlgBuilder.Create(_T("WorkGroupButtons.xml"), (UINT)0,  &cb, &m_PaintManager);
	ASSERT(pRoot);
	m_PaintManager.AttachDialog(pRoot);
	m_PaintManager.AddNotifier(this);
}

void CWorkGroupButtons::OnFinalMessage( HWND hWnd )
{
	WindowImplBase::OnFinalMessage(hWnd);
}

CControlUI* CWorkGroupButtons::CreateControl( LPCTSTR pstrClass )
{
	return NULL;
}

DuiLib::CDuiString CWorkGroupButtons::GetSkinFolder()
{
	return _T("skin\\nTalkRes");
}

DuiLib::CDuiString CWorkGroupButtons::GetSkinFile()
{
	return _T("WorkGroupButtons.xml");
}

void CWorkGroupButtons::SetClientRect( CRect rc )
{
	MoveWindow(GetHWND(), rc.left, rc.top, rc.Width(), rc.Height(), TRUE);
}

void CWorkGroupButtons::_OnNotifyBtnAddClick( TNotifyUI& msg )
{
	ASSERT(m_pCallBack);

	if(m_pCallBack != NULL)
	{
		m_pCallBack->OnButtonClicked(Add);
	}
}

void CWorkGroupButtons::_OnNotifyBtnChatClick( TNotifyUI& msg )
{
	ASSERT(m_pCallBack);

	if(m_pCallBack != NULL)
	{
		m_pCallBack->OnButtonClicked(Chat);
	}
}

void CWorkGroupButtons::_OnNotifyBtnMemoClick( TNotifyUI& msg )
{
	ASSERT(m_pCallBack);

	if(m_pCallBack != NULL)
	{
		m_pCallBack->OnButtonClicked(Memo);
	}
}

void CWorkGroupButtons::SetButtonReadOnly( bool bReadOnly, BUTTONS button )
{
	if(button == Add || button == All)
	{
		ASSERT(m_pBtnAdd);
		if(m_pBtnAdd)
		{
			m_pBtnAdd->SetEnabled(bReadOnly);
		}
		
	}

	if(button == Chat || button == All)
	{
		ASSERT(m_pBtnChat);
		if(m_pBtnChat)
		{
			m_pBtnChat->SetEnabled(bReadOnly);
		}
		
	}

	if(button == Memo || button == All)
	{
		ASSERT(m_pBtnMemo);
		if(m_pBtnMemo)
		{
			m_pBtnMemo->SetEnabled(bReadOnly);
		}
		
	}

}

LRESULT CWorkGroupButtons::OnNcHitTest( UINT uMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled )
{
	return HTCLIENT;
}


